<?php

namespace Lewisdale\App\Controllers;

use Lewisdale\App\Models\Repositories\UserRepository;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Slim\Views\Twig;

class LoginController {
    function __construct(
        private readonly Twig $view,
        private readonly UserRepository $users,
    )
    {
    }

    public function index(ServerRequestInterface $request, ResponseInterface $response): ResponseInterface {
        return $this->view->render($response, 'account/login.twig.html', []);
    }

    public function login(ServerRequestInterface $request, ResponseInterface $response): ResponseInterface {
        $body = $request->getParsedBody();
        $email = $body['email'];
        $password = $body['password'];

        $user = $this->users->validateCredentials($email, $password);

        if (!$user) {
            return $this->view->render($response, 'account/login.twig.html', ['error' => 'Invalid email or password']);
        }

        $_SESSION['user'] = $user->id;

        return $response->withStatus(302)->withHeader('Location', '/feed');
    }
}