<?php
declare(strict_types=1);


namespace Lewisdale\App\Models\Repositories;

use Doctrine\ORM\EntityManager;
use Doctrine\ORM\EntityRepository;
use Lewisdale\App\Models\Data\User;
use Psr\Log\LoggerInterface;
use function DI\string;

/** @extends EntityRepository<User> */
class UserRepository extends EntityRepository {
    private readonly LoggerInterface $logger;

    public function __construct(EntityManager $em, LoggerInterface $logger)
    {
        parent::__construct($em, $em->getClassMetadata(User::class));
        $this->logger = $logger;
    }

    public function findByEmail(string $email): ?User {
        return $this->findOneBy(['email' => $email]);
    }

    public function validateCredentials(string $email, string $password): ?User {
        $user = $this->findByEmail($email);
        if (!$user || !$user->validate($password)) {
            $this->logger->warning('Invalid credentials.', ['email' => $email, 'password' => $password, 'user' => $user, 'valid' => $user?->validate($password)]);
            return null;
        }

        return $user;
    }

    public function save(User $user): void {
        $this->_em->persist($user);
        $this->_em->flush();
    }
}