<?php
declare(strict_types=1);


namespace Lewisdale\App\Tools\Console;

use Doctrine\ORM\EntityManager;
use Doctrine\ORM\Tools\Console\Command\SchemaTool\AbstractCommand;
use Lewisdale\App\Models\Data\User;
use Lewisdale\App\Models\Repositories\FeedRepository;
use Lewisdale\App\Models\Repositories\UserRepository;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name: 'user:create', description: 'Create a user')]
class CreateUser extends Command {
    public function __construct(private readonly EntityManager $em,
                                private readonly UserRepository $userRepository)
    {
        parent::__construct();
    }

    protected function configure(): void {
        $this->addArgument('email', InputArgument::REQUIRED, "The user's email address")
            ->addArgument('password', InputArgument::REQUIRED, "The user's password");
    }

    protected function execute(InputInterface $input, OutputInterface $output): int {
        $email = $input->getArgument('email');
        $password = $input->getArgument('password');

        $user = $this->userRepository->findOneBy(['email' => $email]);
        if ($user !== null) {
            $output->writeln('<error>User with email ' . $email . ' already exists.</error>');
            return 1;
        }

        $user = new User('', $email);
        $user->updatePassword($password);

        $this->userRepository->save($user);
        $output->writeln("<info>User $email created!</info>");
        return 0;
    }
}